@@ -50,12 +50,12 @@ struct TrackerExtractClass {
 
 GType           tracker_extract_get_type                (void);
 TrackerExtract *tracker_extract_new                     (gboolean                disable_shutdown,
-                                                         gboolean                force_internal_extractors,
                                                          const gchar            *force_module);
 
 void            tracker_extract_file                    (TrackerExtract         *extract,
                                                          const gchar            *file,
                                                          const gchar            *mimetype,
+                                                         const gchar            *graph,
                                                          GCancellable           *cancellable,
                                                          GAsyncReadyCallback     cb,
                                                          gpointer                user_data);
