@@ -38,7 +38,9 @@
 #include <sys/resource.h>
 #endif
 
+#ifdef HAVE_LIBMEDIAART
 #include <libmediaart/mediaart.h>
+#endif
 
 #include <libtracker-common/tracker-log.h>
 #include <libtracker-common/tracker-dbus.h>
@@ -69,14 +71,11 @@
 	"\n" \
 	"  http://www.gnu.org/licenses/gpl.txt\n"
 
-#define QUIT_TIMEOUT 30 /* 1/2 minutes worth of seconds */
-
 static GMainLoop *main_loop;
 
 static gint verbosity = -1;
 static gchar *filename;
 static gchar *mime_type;
-static gboolean force_internal_extractors;
 static gchar *force_module;
 static gboolean version;
 
@@ -96,10 +95,6 @@ static GOptionEntry entries[] = {
 	  G_OPTION_ARG_STRING, &mime_type,
 	  N_("MIME type for file (if not provided, this will be guessed)"),
 	  N_("MIME") },
-	{ "force-internal-extractors", 'i', 0,
-	  G_OPTION_ARG_NONE, &force_internal_extractors,
-	  N_("Force internal extractors over 3rd parties like libstreamanalyzer"),
-	  NULL },
 	{ "force-module", 'm', 0,
 	  G_OPTION_ARG_STRING, &force_module,
 	  N_("Force a module to be used for extraction (e.g. \"foo\" for \"foo.so\")"),
@@ -273,9 +268,11 @@ run_standalone (TrackerConfig *config)
 
 	tracker_locale_init ();
 
+#ifdef HAVE_LIBMEDIAART
 	if (!media_art_init ()) {
 		g_warning ("Could not initialize media art, will not be available");
 	}
+#endif
 
 	/* This makes sure we don't steal all the system's resources */
 	initialize_priority_and_scheduling (tracker_config_get_sched_idle (config),
@@ -284,14 +281,14 @@ run_standalone (TrackerConfig *config)
 	file = g_file_new_for_commandline_arg (filename);
 	uri = g_file_get_uri (file);
 
-	object = tracker_extract_new (TRUE,
-	                              force_internal_extractors,
-	                              force_module);
+	object = tracker_extract_new (TRUE, force_module);
 
 	if (!object) {
 		g_object_unref (file);
 		g_free (uri);
+#ifdef HAVE_LIBMEDIAART
 		media_art_shutdown ();
+#endif
 		tracker_locale_shutdown ();
 		return EXIT_FAILURE;
 	}
@@ -304,7 +301,9 @@ run_standalone (TrackerConfig *config)
 	g_object_unref (file);
 	g_free (uri);
 
+#ifdef HAVE_LIBMEDIAART
 	media_art_shutdown ();
+#endif
 	tracker_locale_shutdown ();
 
 	return EXIT_SUCCESS;
@@ -346,20 +345,6 @@ main (int argc, char *argv[])
 		return EXIT_FAILURE;
 	}
 
-	if (force_internal_extractors && force_module) {
-		gchar *help;
-
-		g_printerr ("%s\n\n",
-		            _("Options --force-internal-extractors and --force-module can't be used together"));
-
-		help = g_option_context_get_help (context, TRUE, NULL);
-		g_option_context_free (context);
-		g_printerr ("%s", help);
-		g_free (help);
-
-		return EXIT_FAILURE;
-	}
-
 	g_option_context_free (context);
 
 	if (version) {
@@ -401,9 +386,7 @@ main (int argc, char *argv[])
 	                                    tracker_db_manager_get_first_index_done () == FALSE);
 	tracker_memory_setrlimits ();
 
-	extract = tracker_extract_new (TRUE,
-	                               force_internal_extractors,
-	                               force_module);
+	extract = tracker_extract_new (TRUE, force_module);
 
 	if (!extract) {
 		g_object_unref (config);
@@ -427,9 +410,11 @@ main (int argc, char *argv[])
 
 	tracker_locale_init ();
 
+#ifdef HAVE_LIBMEDIAART
 	if (!media_art_init ()) {
 		g_warning ("Could not initialize media art, will not be available");
 	}
+#endif
 
 	controller = tracker_extract_controller_new (decorator);
 	tracker_miner_start (TRACKER_MINER (decorator));
@@ -445,7 +430,9 @@ main (int argc, char *argv[])
 	tracker_miner_stop (TRACKER_MINER (decorator));
 
 	/* Shutdown subsystems */
+#ifdef HAVE_LIBMEDIAART
 	media_art_shutdown ();
+#endif
 	tracker_locale_shutdown ();
 
 	g_object_unref (extract);
